@@ -2,6 +2,6 @@ from . import events_received_objs
 from . import events_sent_objs
 from . import mixins
 from . import registration_objs
-from .logger import logger
+from .logger import logger, log_errors
 from .sdk import StreamDeck, Action
 from .utils import image_file_to_base64, image_bytes_to_base64
